@@ -1,14 +1,13 @@
-import contextlib
-import gzip
-import zipfile
-from pathlib import Path
-
 import nibabel
 import numpy as np
 
+from ..utils import open_nii_gz_file, unpack
 from .const import ANATOMICAL_STRUCTURES, LABELS
 
 
+ARCHIVE_ROOT = 'Totalsegmentator_dataset'
+
+
 def add_labels(scope):
     def make_loader(label):
         def loader(i, _meta):
@@ -25,7 +24,7 @@ def add_masks(scope):
         def loader(i, _base):
             file = f'{i}/segmentations/{anatomical_structure}.nii.gz'
 
-            with unpack(_base, file) as (unpacked, is_unpacked):
+            with unpack(_base, file, ARCHIVE_ROOT, '.zip') as (unpacked, is_unpacked):
                 if is_unpacked:
                     return np.asarray(nibabel.load(unpacked).dataobj)
                 else:
@@ -36,21 +35,3 @@ def add_masks(scope):
 
     for anatomical_structure in ANATOMICAL_STRUCTURES:
         scope[anatomical_structure] = make_loader(anatomical_structure)
-
-
-@contextlib.contextmanager
-def unpack(root: str, relative: str):
-    unpacked = Path(root) / relative
-
-    if unpacked.exists():
-        yield unpacked, True
-    else:
-        with zipfile.Path(root, str(Path('Totalsegmentator_dataset', relative))).open('rb') as unpacked:
-            yield unpacked, False
-
-
-@contextlib.contextmanager
-def open_nii_gz_file(unpacked):
-    with gzip.GzipFile(fileobj=unpacked) as nii:
-        nii = nibabel.FileHolder(fileobj=nii)
-        yield nibabel.Nifti1Image.from_file_map({'header': nii, 'image': nii})
